﻿Module Module1
    '' This routine is used to control the single acquisition of the analog input channels of the data acquisition card, and the number of points to be acquired per channel each time needs to be set.
    '' The applicable models for this routine are:
    '' PCI-225x
    '' PCI-3xxx
    '' PCI-5xxx

    Sub Main()

        Dim DevIndex As Integer = 0
        Dim rst As Integer
        Dim i As Integer
        Dim AiValue(8000) As Single
        Dim AiFifoUsdw As Integer

        ' Open the device
        rst = OpenDevice(DevIndex)
        If (rst < 0) Then Return

        ' Set the wiring mode of Ai to RSE
        rst = SetAiConnectType(DevIndex, 0)
        If (rst < 0) Then Return

        ' Set the selection of Ai acquisition channels
        ' Here, channels ai 0 to ai 7 are selected, a total of 8 channels.
        rst = SetAiChannelSelect(DevIndex, &HFF)

        ' Set the Ai acquisition mode to OneShot
        rst = SetAiSampleMode(DevIndex, 1)
        If (rst < 0) Then Return

        ' Set the Ai sampling period to 10000ns, that is, 100kS/s
        rst = SetAiSamplePeriod(DevIndex, 10000)
        If (rst < 0) Then Return

        ' Set the Ai range to 1.
        ' For the PCI-3000 series, channels 0 to 7 are all set to range 1 here.
        ' For the PCI-225x/5000 series, there is no need to set it 8 times in a loop, once is enough.
        For i = 0 To 7 Step 1
            rst = SetAiRange(DevIndex, 1, i)
            If (rst < 0) Then Return
        Next i

        ' Set the number of Ai OneShot points, 1000 points are acquired per channel.
        rst = SetAiOneShotCount(DevIndex, 1000)
        If (rst < 0) Then Return

        ' Set the Ai trigger source, Ai software trigger.
        rst = SetAiTrigSource(DevIndex, 0)
        If (rst < 0) Then Return

        ' Set Ai to be ready, AiReady.
        rst = AiReady(DevIndex, 1)
        If (rst < 0) Then Return

        ' Issue the Ai software trigger command.
        rst = SetAiSoftTrig(DevIndex)
        If (rst < 0) Then Return

        ' Read the data obtained from Ai OneShot.
        ' Here, 1000 points are read from each channel. Since 8 channels were enabled before, a total of 8000 points are stored in AiValue.
        ' The data of channel ai 0 is from AiValue[0] to AiValue[999].
        ' The data of channel ai 1 is from AiValue[1000] to AiValue[1999].
        ' The data of channel ai 2 is from AiValue[2000] to AiValue[2999].
        ' The data of channel ai 3 is from AiValue[3000] to AiValue[3999].
        ' The data of channel ai 4 is from AiValue[4000] to AiValue[4999].
        ' The data of channel ai 5 is from AiValue[5000] to AiValue[5999].
        ' The data of channel ai 6 is from AiValue[6000] to AiValue[6999].
        ' The data of channel ai 7 is from AiValue[7000] to AiValue[7999].
        rst = GetAiData(DevIndex, 1000, AiValue(0), AiFifoUsdw, 2000)
        If (rst < 0) Then Return

        Console.WriteLine("GetAiData Success.")

        ' Clear the Ai software trigger flag.
        rst = ClearAiSoftTrig(DevIndex)
        If (rst < 0) Then Return

        ' Clear the Ai ready flag.
        rst = AiReady(DevIndex, 0)
        If (rst < 0) Then Return

        ' Close the device.
        rst = CloseDevice(DevIndex)
        If (rst < 0) Then Return

        Console.WriteLine("Press any key to quit.")
        Console.ReadKey()

    End Sub

End Module