﻿Module Module1
    ' This routine controls the data acquisition card to output an infinite non - cyclic analog arbitrary wave signal.
    ' The applicable models for this routine are:
    ' PCI-2253
    ' PCI-31xx

    Sub Main()

        Dim rst As Integer
        Dim DevIndex As Integer = 0
        Dim i As Integer
        Dim j As Integer
        Dim WaveData As Single

        ' Open the device
        rst = OpenDevice(DevIndex)
        If (rst < 0) Then Return

        ' Clear the waveform FIFO of Ao 0
        rst = ClearAoFifo(DevIndex, 0)
        If (rst < 0) Then Return

        ' Set the output mode of Ao 0 to infinite non - cyclic mode
        rst = SetAoMode(DevIndex, 0, 2)
        If (rst < 0) Then Return

        ' Set the output sampling rate of Ao 0
        ' Here, it is set to 100000ns, which is 10kS/s
        rst = SetAoSamplePeriod(DevIndex, 0, 100000)
        If (rst < 0) Then Return

        ' Set the trigger source of Ao 0, software trigger for Ao 0
        rst = SetAoTrigSource(DevIndex, 0, 2)
        If (rst < 0) Then Return

        ' First, send 1000 points of waveform data to the hardware
        For i = 0 To 999 Step 1
            WaveData = Rnd()
            rst = SetAoFifo(DevIndex, 0, WaveData)
            If (rst < 0) Then Return
        Next i

        ' Set Ao ready, AoReady
        rst = AoReady(DevIndex, 0, 1)
        If (rst < 0) Then Return

        ' Issue the software trigger command for Ao 0
        rst = SetAoSoftTrig(DevIndex, 0)
        If (rst < 0) Then Return

        ' Start sending non - cyclic waveform data to the hardware
        ' Here, only 10 times of sending are used as an example
        For i = 0 To 9 Step 1
            ' Send another 1000 points of waveform data to the hardware
            For j = 0 To 999 Step 1
                WaveData = Rnd()
                rst = SetAoFifo(DevIndex, 0, WaveData)
                If (rst < 0) Then Return
            Next j

            Console.WriteLine("send 1000 points to device. times: {0}", i)

            ' Send 1000 points of waveform data to the hardware every 100ms
            ' Ensure that there is enough data in the hardware FIFO but it does not overflow
            System.Threading.Thread.Sleep(100)
        Next i

        ' Clear the software trigger flag of Ao 0
        rst = ClearAoSoftTrig(DevIndex, 0)
        If (rst < 0) Then Return

        ' Clear the ready flag of Ao 0
        rst = AoReady(DevIndex, 0, 0)
        If (rst < 0) Then Return

        ' Close the device
        rst = CloseDevice(DevIndex)
        If (rst < 0) Then Return

        Console.WriteLine("Press any key to quit.")
        Console.ReadKey()

    End Sub

End Module