﻿Module Module1
    ' This routine controls the analog output channel of the data acquisition card to output an arbitrary wave signal a specified number of times.
    ' The applicable models for this routine are:
    ' PCI-2253
    ' PCI-31xx

    Sub Main()

        Dim rst As Integer
        Dim DevIndex As Integer = 0
        Dim i As Integer
        Dim WaveData(100) As Single

        ' Open the device
        rst = OpenDevice(DevIndex)
        If (rst < 0) Then Return

        ' Clear the waveform FIFO of Ao 0
        rst = ClearAoFifo(DevIndex, 0)
        If (rst < 0) Then Return

        ' Set the output mode of Ao 0 to n-cycle mode
        rst = SetAoMode(DevIndex, 0, 1)
        If (rst < 0) Then Return

        ' Set the output sampling rate of Ao 0
        ' Here, it is set to 100000ns, that is, 10kS/s
        rst = SetAoSamplePeriod(DevIndex, 0, 100000)
        If (rst < 0) Then Return

        ' Set the number of output waveform cycles of Ao 0
        ' Here, it is set to output 10 times. If set to 0, it means infinite loop output.
        rst = SetAoNCycleCount(DevIndex, 0, 10)
        If (rst < 0) Then Return

        ' Set the trigger source of Ao 0, software trigger for Ao 0
        rst = SetAoTrigSource(DevIndex, 0, 2)
        If (rst < 0) Then Return

        ' Generate 100-point waveform data
        For i = 0 To 99 Step 1
            WaveData(i) = i / 100 * 5
        Next i

        ' Set the waveform data of Ao 0
        ' Write the 100-point waveform data to the hardware
        For i = 0 To 99 Step 1
            rst = SetAoFifo(DevIndex, 0, WaveData(i))
            If (rst < 0) Then Return
        Next i

        ' Set Ao ready, AoReady
        rst = AoReady(DevIndex, 0, 1)
        If (rst < 0) Then Return

        ' Issue the software trigger command for Ao 0
        rst = SetAoSoftTrig(DevIndex, 0)
        If (rst < 0) Then Return

        ' Clear the software trigger flag of Ao 0
        rst = ClearAoSoftTrig(DevIndex, 0)
        If (rst < 0) Then Return

        ' Clear the ready flag of Ao 0
        rst = AoReady(DevIndex, 0, 0)
        If (rst < 0) Then Return

        ' Close the device
        rst = CloseDevice(DevIndex)
        If (rst < 0) Then Return

        Console.WriteLine("Press any key to quit.")
        Console.ReadKey()

    End Sub

End Module