﻿Module Module1
    ' This routine is used to control the continuous acquisition of the digital input channels of the data acquisition card.
    ' The applicable models for this routine are:
    ' PCI-1132
    ' PCI-1316
    ' PCI-225x
    ' PCI-3xxx
    ' PCI-5xxx

    Sub Main()

        Dim rst As Integer
        Dim i As Integer
        Dim DevIndex As Integer = 0
        Dim DiValue(1000) As UInteger
        Dim DiFifoUsdw As UInteger

        ' Open the device
        rst = OpenDevice(DevIndex)
        If (rst < 0) Then Return

        ' Set the digital I/O direction
        ' Since the digital I/O of PCI-225x/3000/5000 can be set as input or output,
        ' here all are set as input.
        ' For models whose digital I/O does not support setting, this step can be skipped.
        rst = SetDioDir(DevIndex, &H7FFFFFFF)
        If (rst < 0) Then Return

        ' Set the Di sensitivity
        rst = SetDiSensitivity(DevIndex, 20000)
        If (rst < 0) Then Return

        ' Set the Di acquisition mode to continuous acquisition
        rst = SetDiSampleMode(DevIndex, 2)
        If (rst < 0) Then Return

        ' Set the Di sampling period to 10000ns, that is, 100kS/s
        rst = SetDiSamplePeriod(DevIndex, 10000)
        If (rst < 0) Then Return

        ' Set the Di trigger source, Di software trigger
        rst = SetDiTrigSource(DevIndex, 1)
        If (rst < 0) Then Return

        ' Set Di ready, DiReady
        rst = DiReady(DevIndex, 1)
        If (rst < 0) Then Return

        ' Issue the Di software trigger command
        rst = SetDiSoftTrig(DevIndex)
        If (rst < 0) Then Return

        ' Read the data obtained from the continuous acquisition of Di
        ' For continuous and uninterrupted data acquisition, just call the GetDiData function in a loop.
        ' The obtained data is the continuously and uninterruptedly acquired data. Here, it is only looped 10 times as an example.
        For i = 0 To 9 Step 1
            rst = GetDiData(DevIndex, 1000, DiValue(0), DiFifoUsdw, 2000)
            If (rst < 0) Then Return
            Console.WriteLine("Call GetDiData times: {0}", i)
        Next i

        ' Clear the Di software trigger flag
        rst = ClearDiSoftTrig(DevIndex)
        If (rst < 0) Then Return

        ' Clear the Di ready flag
        rst = DiReady(DevIndex, 0)
        If (rst < 0) Then Return

        ' Close the device
        rst = CloseDevice(DevIndex)
        If (rst < 0) Then Return

        Console.WriteLine("Press any key to quit.")
        Console.ReadKey()

    End Sub
End Module