﻿Module Module1
    ' This routine is used to control the edge counting of the digital input channels of the data acquisition card.
    ' The applicable models for this routine are:
    ' PCI-1132
    ' PCI-1316
    ' PCI-225x
    ' PCI-3xxx
    ' PCI-5xxx

    Sub Main()

        Dim rst As Integer
        Dim i As Integer
        Dim DevIndex As Integer = 0
        Dim DiCountValue As UInteger

        ' Open the device
        rst = OpenDevice(DevIndex)
        If (rst < 0) Then Return

        ' Set the digital I/O direction
        ' Since the digital I/O of PCI-225x/3000/5000 can be set as input or output,
        ' here all are set as input.
        ' For models whose digital I/O does not support setting, this step can be skipped.
        rst = SetDioDir(DevIndex, &HFFFFFFFF)
        If (rst < 0) Then Return

        ' Set the Di sensitivity
        rst = SetDiSensitivity(DevIndex, 20000000)
        If (rst < 0) Then Return

        ' Set the Di counting edge, set it to rising edge counting.
        ' Each bit of the parameter corresponds to a Di channel.
        ' Here, all 32 channels are set to rising edge counting.
        rst = SetDiCountEdge(DevIndex, &HFFFFFFFF)
        If (rst < 0) Then Return

        ' Enable the Di counting function
        rst = SetDiCountEn(DevIndex, 1)
        If (rst < 0) Then Return

        ' Reset the count value of Di 0 to zero
        rst = ClearDiCountValue(DevIndex, 0)
        If (rst < 0) Then Return

        System.Threading.Thread.Sleep(10)

        ' Read the Di counter value
        ' Here, it is read 10 times.
        For i = 0 To 9 Step 1
            rst = GetDiCountValue(DevIndex, 0, DiCountValue)
            If (rst < 0) Then Return
            Console.WriteLine("Call GetDiCountValue {0} times. DiCountValue is: {1}", i + 1, DiCountValue)
            System.Threading.Thread.Sleep(1000)
        Next i

        ' Disable the Di counting function
        rst = SetDiCountEn(DevIndex, 0)
        If (rst < 0) Then Return

        ' Close the device
        rst = CloseDevice(DevIndex)
        If (rst < 0) Then Return

        Console.WriteLine("Press any key to quit.")
        Console.ReadKey()

    End Sub
End Module