﻿Module Module1
    ' This routine is used to control the single acquisition of the digital input channels of the data acquisition card, and the number of points to be acquired per channel each time needs to be set.
    ' The applicable models for this routine are:
    ' PCI-1132
    ' PCI-1316
    ' PCI-225x
    ' PCI-3xxx
    ' PCI-5xxx

    Sub Main()
        Dim rst As Integer
        Dim i As Integer
        Dim DevIndex As Integer = 0
        Dim DiValue(1000) As UInteger
        Dim DiFifoUsdw As UInteger

        ' Open the device
        rst = OpenDevice(DevIndex)
        If (rst < 0) Then Return

        ' Set the digital I/O direction
        ' Since the digital I/O of PCI-225x/3000/5000 can be set as input or output,
        ' here all are set as input.
        ' For models whose digital I/O does not support setting, this step can be skipped.
        rst = SetDioDir(DevIndex, &HFFFFFFFF)
        If (rst < 0) Then Return

        ' Set the Di sensitivity
        rst = SetDiSensitivity(DevIndex, 20000)
        If (rst < 0) Then Return

        ' Set the Di acquisition mode to OneShot
        rst = SetDiSampleMode(DevIndex, 1)
        If (rst < 0) Then Return

        ' Set the Di sampling period to 10000ns, that is, 100kS/s
        rst = SetDiSamplePeriod(DevIndex, 10000)
        If (rst < 0) Then Return

        ' Set the number of Di OneShot points, 1000 points are acquired.
        rst = SetDiOneShotCount(DevIndex, 1000)
        If (rst < 0) Then Return

        ' Set the Di trigger source, Di software trigger
        rst = SetDiTrigSource(DevIndex, 1)
        If (rst < 0) Then Return

        ' Set Di ready, DiReady
        rst = DiReady(DevIndex, 1)
        If (rst < 0) Then Return

        ' Issue the Di software trigger command
        rst = SetDiSoftTrig(DevIndex)
        If (rst < 0) Then Return

        ' Read the data obtained from Di OneShot
        rst = GetDiData(DevIndex, 1000, DiValue(0), DiFifoUsdw, 2000)
        If (rst < 0) Then Return

        Console.WriteLine("GetDiData Success.")

        ' Clear the Di software trigger flag
        rst = ClearDiSoftTrig(DevIndex)
        If (rst < 0) Then Return

        ' Clear the Di ready flag
        rst = DiReady(DevIndex, 0)
        If (rst < 0) Then Return

        ' Close the device
        rst = CloseDevice(DevIndex)
        If (rst < 0) Then Return

        Console.WriteLine("Press any key to quit.")
        Console.ReadKey()
    End Sub
End Module