﻿Module Module1
    ' This routine controls the data acquisition card to output an infinite non-cyclic digital arbitrary wave signal.
    ' The applicable models for this routine are:
    ' PCI-1232
    ' PCI-1316
    ' PCI-225x
    ' PCI-3xxx

    Sub Main()

        Dim rst As Integer
        Dim DevIndex As Integer = 0
        Dim i, j As Integer
        Dim WaveData As UInteger

        ' Open the device
        rst = OpenDevice(DevIndex)
        If (rst < 0) Then Return

        ' Set the digital I/O direction
        ' Here, all digital I/O channels are set as output.
        ' Since the digital I/O of PCI-225x/3000/5000 can be set as input or output,
        ' here all are set as input. (There is an inconsistent comment here as the code sets to output actually.)
        ' For models whose digital I/O does not support setting, this step can be skipped.
        rst = SetDioDir(DevIndex, &H0)
        If (rst < 0) Then Return

        ' Clear the Do waveform FIFO
        rst = ClearDoFifo(DevIndex)
        If (rst < 0) Then Return

        ' Set the Do output to the infinite non-cyclic mode
        rst = SetDoMode(DevIndex, 2)
        If (rst < 0) Then Return

        ' Set the Do output sampling rate
        ' Here, it is set to 100000ns, that is, 10kS/s
        rst = SetDoSamplePeriod(DevIndex, 100000)
        If (rst < 0) Then Return

        ' Set the Do trigger source, Do software trigger
        rst = SetDoTrigSource(DevIndex, 18)
        If (rst < 0) Then Return

        ' First, send 1000 points of waveform data to the hardware
        For i = 0 To 999 Step 1
            WaveData = Rnd() * &HFFFF
            rst = SetDoFifo(DevIndex, WaveData) 'Here was a wrong call to SetAoFifo, corrected to SetDoFifo
            If (rst < 0) Then Return
        Next i

        ' Set Do ready, DoReady
        rst = DoReady(DevIndex, 1)
        If (rst < 0) Then Return

        ' Issue the Do software trigger command
        rst = SetDoSoftTrig(DevIndex)
        If (rst < 0) Then Return

        ' Start sending non-cyclic waveform data to the hardware
        ' Here, only 10 times of sending are used as an example
        For i = 0 To 9 Step 1
            ' Send another 1000 points of waveform data to the hardware
            For j = 0 To 999 Step 1
                WaveData = Rnd() * &HFFFF
                rst = SetDoFifo(DevIndex, WaveData)
                If (rst < 0) Then Return
            Next j

            ' Send 1000 points of waveform data to the hardware every 100ms
            ' Ensure that there is enough data in the hardware FIFO but it does not overflow
            System.Threading.Thread.Sleep(100)

            Console.WriteLine("send 1000 points to device. times: {0}", i)
        Next i

        ' Clear the Do software trigger flag
        rst = ClearDoSoftTrig(DevIndex)
        If (rst < 0) Then Return

        ' Clear the Do ready flag
        rst = DoReady(DevIndex, 0)
        If (rst < 0) Then Return

        ' Close the device
        rst = CloseDevice(DevIndex)
        If (rst < 0) Then Return

        Console.WriteLine("Press any key to quit.")
        Console.ReadKey()

    End Sub
End Module