﻿Module Module1
    ' This routine controls the digital output channels of the data acquisition card to output an arbitrary wave signal a specified number of times.
    ' The applicable models for this routine are:
    ' PCI-1232
    ' PCI-1316
    ' PCI-225x
    ' PCI-3xxx

    Sub Main()

        Dim rst As Integer
        Dim DevIndex As Integer = 0
        Dim i As Integer
        Dim WaveData(100) As UInteger

        ' Open the device
        rst = OpenDevice(DevIndex)
        If (rst < 0) Then Return

        ' Set the digital I/O direction
        ' Here, all digital I/O channels are set as output.
        ' Since the digital I/O of PCI-225x/3000/5000 can be set as input or output,
        ' here all are set as input. (There is an inconsistent comment here as the code sets to output actually.)
        ' For models whose digital I/O does not support setting, this step can be skipped.
        rst = SetDioDir(DevIndex, &H0)
        If (rst < 0) Then Return

        ' Clear the Do waveform FIFO
        rst = ClearDoFifo(DevIndex)
        If (rst < 0) Then Return

        ' Set the Do output to the n-cycle mode
        rst = SetDoMode(DevIndex, 1)
        If (rst < 0) Then Return

        ' Set the Do output sampling rate
        ' Here, it is set to 100000ns, that is, 10kS/s
        rst = SetDoSamplePeriod(DevIndex, 100000)
        If (rst < 0) Then Return

        ' Set the number of Do output waveform cycles
        ' Here, it is set to output 10 times. If set to 0, it means infinite loop output.
        rst = SetDoNCycleCount(DevIndex, 10)
        If (rst < 0) Then Return

        ' Set the Do trigger source, Do software trigger
        rst = SetDoTrigSource(DevIndex, 18)
        If (rst < 0) Then Return

        ' Generate 100-point waveform data
        For i = 0 To 99 Step 1
            WaveData(i) = Rnd() * &HFFFF
        Next i

        ' Set the Do waveform data
        ' Write the 100-point waveform data to the hardware
        For i = 0 To 99 Step 1
            rst = SetDoFifo(DevIndex, WaveData(i))
            If (rst < 0) Then Return
        Next i

        ' Set Do ready, DoReady
        rst = DoReady(DevIndex, 1)
        If (rst < 0) Then Return

        ' Issue the Do software trigger command
        rst = SetDoSoftTrig(DevIndex)
        If (rst < 0) Then Return

        Console.WriteLine("Success.")

        ' Clear the Do software trigger flag
        rst = ClearDoSoftTrig(DevIndex)
        If (rst < 0) Then Return

        ' Clear the Do ready flag
        rst = DoReady(DevIndex, 0)
        If (rst < 0) Then Return

        ' Close the device
        rst = CloseDevice(DevIndex)
        If (rst < 0) Then Return

        Console.WriteLine("Press any key to quit.")
        Console.ReadKey()

    End Sub
End Module